==> scichains-cv-4.3.6-sources.jar: net/algart/executors/modules/opencv/common/UMatToNumbers.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2024 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.common;

import net.algart.executors.modules.opencv.util.O2SMat;
import net.algart.executors.api.data.SNumbers;
import org.bytedeco.opencv.opencv_core.*;

public abstract class UMatToNumbers extends MatToNumbers {
    protected UMatToNumbers() {
    }

    @Override
    public void process() {
        if (!useGPU()) {
            super.process();
            return;
        }
        final UMat source = O2SMat.toUMat(getInputMat(), allowInputPackedBits());
        setStartProcessingTimeStamp();
        final SNumbers result = analyse(source);
        setEndProcessingTimeStamp();
        getNumbers().setTo(result);
    }

    public abstract SNumbers analyse(UMat source);
}

==> scichains-cv-4.4.11-sources.jar: net/algart/executors/modules/opencv/common/UMatToNumbers.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2025 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.common;

import net.algart.executors.api.data.SNumbers;
import net.algart.executors.modules.opencv.util.O2SMat;
import org.bytedeco.opencv.opencv_core.UMat;

public abstract class UMatToNumbers extends MatToNumbers {
    protected UMatToNumbers() {
    }

    @Override
    public void process() {
        if (!useGPU()) {
            super.process();
            return;
        }
        final UMat source = O2SMat.toUMat(getInputMat(), allowInputPackedBits());
        setStartProcessingTimeStamp();
        final SNumbers result = analyse(source);
        setEndProcessingTimeStamp();
        getNumbers().setTo(result);
    }

    public abstract SNumbers analyse(UMat source);
}
